@@ -53,6 +53,7 @@ typedef struct _GMainLoop               GMainLoop;
  * representing an event source.
  */
 typedef struct _GSource                 GSource;
+typedef struct _GSourcePrivate          GSourcePrivate;
 
 /**
  * GSourceCallbackFuncs:
@@ -157,7 +158,8 @@ struct _GSource
   GSource *next;
 
   char    *name;
-  gpointer reserved2;
+
+  GSourcePrivate *priv;
 };
 
 struct _GSourceCallbackFuncs
@@ -358,17 +360,21 @@ void g_source_set_callback_indirect (GSource              *source,
                                      gpointer              callback_data,
                                      GSourceCallbackFuncs *callback_funcs);
 
-void     g_source_add_poll         (GSource        *source,
-                                    GPollFD        *fd);
-void     g_source_remove_poll      (GSource        *source,
-                                    GPollFD        *fd);
+void     g_source_add_poll            (GSource        *source,
+				       GPollFD        *fd);
+void     g_source_remove_poll         (GSource        *source,
+				       GPollFD        *fd);
+
+void     g_source_add_child_source    (GSource        *source,
+				       GSource        *child_source);
+void     g_source_remove_child_source (GSource        *source,
+				       GSource        *child_source);
 
 #ifndef G_DISABLE_DEPRECATED
 void     g_source_get_current_time (GSource        *source,
                                     GTimeVal       *timeval);
 #endif
-void     g_source_get_time         (GSource        *source,
-                                    GTimeSpec      *timespec);
+gint64   g_source_get_time         (GSource        *source);
 
  /* void g_source_connect_closure (GSource        *source,
                                   GClosure       *closure);
@@ -383,8 +389,9 @@ GSource *g_timeout_source_new_seconds (guint interval);
 
 /* Miscellaneous functions
  */
-void g_get_current_time                 (GTimeVal       *result);
-void g_get_monotonic_time               (GTimeSpec      *result);
+void   g_get_current_time                 (GTimeVal       *result);
+gint64 g_get_monotonic_time               (void);
+gint64 g_get_real_time                    (void);
 
 /* ============== Compat main loop stuff ================== */
 
